==> grizzly-http-2.3.16-sources.jar: org/glassfish/grizzly/http/util/Constants.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2010-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 *
 *
 * This file incorporates work covered by the following copyright and
 * permission notice:
 *
 * Copyright 2004 The Apache Software Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.glassfish.grizzly.http.util;

import java.nio.charset.Charset;
import org.glassfish.grizzly.utils.Charsets;


/**
 * Constants.
 *
 * @author Remy Maucherat
 */
public final class Constants {
    // -------------------------------------------------------------- Constants

    /**
     * CR.
     */
    public static final byte CR = (byte) '\r';


    /**
     * LF.
     */
    public static final byte LF = (byte) '\n';


    /**
     * SP.
     */
    public static final byte SP = (byte) ' ';


    /**
     * HT.
     */
    public static final byte HT = (byte) '\t';


    /**
     * COMMA.
     */
    public static final byte COMMA = (byte) ',';


    /**
     * COLON.
     */
    public static final byte COLON = (byte) ':';


    /**
     * SEMI_COLON.
     */
    public static final byte SEMI_COLON = (byte) ';';


    /**
     * 'A'.
     */
    public static final byte A = (byte) 'A';


    /**
     * 'a'.
     */
    public static final byte a = (byte) 'a';


    /**
     * 'Z'.
     */
    public static final byte Z = (byte) 'Z';


    /**
     * '?'.
     */
    public static final byte QUESTION = (byte) '?';


    /**
     * Lower case offset.
     */
    public static final byte LC_OFFSET = A - a;


    // START SJSAS 6328909
    /**
     * The default response-type
     */
    public final static String DEFAULT_RESPONSE_TYPE =
            /*"text/html; charset=iso-8859-1"*/ null;

    public final static String CHUNKED_ENCODING = "chunked";

    public static final String FORM_POST_CONTENT_TYPE = "application/x-www-form-urlencoded";

    public static final int KEEP_ALIVE_TIMEOUT_IN_SECONDS = 30;
    /**
     * Default max keep-alive count.
     */
    public static final int DEFAULT_MAX_KEEP_ALIVE = 256;

    /**
     * Default HTTP character encoding
     * TODO Grizzly 2.0, by default, parsed the request URI using UTF-8.
     * We should probably do so with query parameters
     */
    public static final String DEFAULT_HTTP_CHARACTER_ENCODING = "ISO-8859-1";
    
    /**
     * Default HTTP {@link Charset}
     */
    public static final Charset DEFAULT_HTTP_CHARSET =
            Charsets.lookupCharset(DEFAULT_HTTP_CHARACTER_ENCODING);

    public static final byte[] IDENTITY = "identity".getBytes(DEFAULT_HTTP_CHARSET);
}

==> grizzly-http-2.4.4-sources.jar: org/glassfish/grizzly/http/util/Constants.java <==
/*
 * Copyright (c) 2010, 2017 Oracle and/or its affiliates. All rights reserved.
 * Copyright 2004 The Apache Software Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.glassfish.grizzly.http.util;

import java.nio.charset.Charset;
import org.glassfish.grizzly.utils.Charsets;


/**
 * Constants.
 *
 * @author Remy Maucherat
 */
public final class Constants {
    // -------------------------------------------------------------- Constants

    /**
     * CR.
     */
    public static final byte CR = (byte) '\r';


    /**
     * LF.
     */
    public static final byte LF = (byte) '\n';


    /**
     * SP.
     */
    public static final byte SP = (byte) ' ';


    /**
     * HT.
     */
    public static final byte HT = (byte) '\t';


    /**
     * COMMA.
     */
    public static final byte COMMA = (byte) ',';


    /**
     * COLON.
     */
    public static final byte COLON = (byte) ':';


    /**
     * SEMI_COLON.
     */
    public static final byte SEMI_COLON = (byte) ';';


    /**
     * 'A'.
     */
    public static final byte A = (byte) 'A';


    /**
     * 'a'.
     */
    public static final byte a = (byte) 'a';


    /**
     * 'Z'.
     */
    public static final byte Z = (byte) 'Z';


    /**
     * '?'.
     */
    public static final byte QUESTION = (byte) '?';


    /**
     * Lower case offset.
     */
    public static final byte LC_OFFSET = A - a;


    // START SJSAS 6328909
    /**
     * The default response-type
     */
    public final static String DEFAULT_RESPONSE_TYPE =
            /*"text/html; charset=iso-8859-1"*/ null;

    public final static String CHUNKED_ENCODING = "chunked";

    public static final String FORM_POST_CONTENT_TYPE = "application/x-www-form-urlencoded";

    public static final int KEEP_ALIVE_TIMEOUT_IN_SECONDS = 30;
    /**
     * Default max keep-alive count.
     */
    public static final int DEFAULT_MAX_KEEP_ALIVE = 256;

    /**
     * Default HTTP character encoding
     * TODO Grizzly 2.0, by default, parsed the request URI using UTF-8.
     * We should probably do so with query parameters
     */
    public static final String DEFAULT_HTTP_CHARACTER_ENCODING =
            System.getProperty(
                    Constants.class.getName() + ".default-character-encoding",
                    "ISO-8859-1");
    
    /**
     * Default HTTP {@link Charset}
     */
    public static final Charset DEFAULT_HTTP_CHARSET =
            Charsets.lookupCharset(DEFAULT_HTTP_CHARACTER_ENCODING);

    public static final byte[] IDENTITY = "identity".getBytes(DEFAULT_HTTP_CHARSET);
}
